# Test Summary
---
This document provides a summary of the tests executed by Agent Evaluation.

> :warning: This tool utilizes generative AI to assess virtual agents and its evaluations may contain errors. **Please thoroughly examine the results below prior to deciding whether to implement an agent.**
---
## Metrics

**Pass Rate** = {{ metrics.pass_rate }} %

---
## Tests
{% for test, result in zip(tests, results) -%}
- [{% if result.passed %}🟢{% else %}🔴{% endif %} {{ test.name }}](#{{ test.name | replace(' ', '-') }})
{% endfor %}

---

{% for test, result in zip(tests, results) -%}
## <a id={{ test.name | replace(' ', '-') }}></a>{% if result.passed %}🟢{% else %}🔴{% endif %} {{ test.name }}

**Steps**
{% for step in test.steps -%}
{{ loop.index }}. {{ step }}
{% endfor %}

**Expected results**
{% for result in test.expected_results -%}
{{ loop.index }}. {{ result }}
{% endfor %}

**Conversation**
```
{% for sender, message in result.conversation -%}
[{{ sender }}] {{ message }}
{% endfor -%}
```

**Result**
{{ result.result }}

**Reasoning**
```
{{ result.reasoning }}
```

---
{% endfor %}





